/* BlinkenLib
   Copyright 2004-2023 Stefan Schuermans <stefan@schuermans.info>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#include "Tools.h"

#include <stdlib.h>

#ifdef WIN32
#include <windows.h>
#include <winsock2.h>
#else
#include <sys/time.h>
#include <unistd.h>
#endif

void *BlinkenMalloc1D(int count1, int size) {
  if (count1 < 1)
    count1 = 1;
  if (size < 1)
    return NULL;

  return malloc(count1 * size);
}

void **BlinkenMalloc2D(int count1, int count2, int size) {
  int sz, i;
  char *p;
  void **ptr;

  if (count1 < 1)
    count1 = 1;
  if (count2 < 1)
    count2 = 1;
  if (size < 1)
    return NULL;

  sz = count1 * sizeof(void *) + count1 * count2 * size;
  p = (char *)malloc(sz);
  if (p == NULL)
    return NULL;

  ptr = (void **)p;
  p += count1 * sizeof(void *);
  for (i = 0; i < count1; i++) {
    ptr[i] = (void *)p;
    p += count2 * size;
  }
  return ptr;
}

#ifdef WIN32

void BlinkenMSleep(unsigned int ms) { Sleep(ms); }

unsigned int BlinkenGetMs(void) { return GetTickCount(); }

#else

void BlinkenMSleep(unsigned int ms) { usleep(ms * 1000); }

unsigned int BlinkenGetMs(void) {
  struct timeval tv;
  gettimeofday(&tv, NULL);
  return (unsigned int)(tv.tv_usec / 1000 + tv.tv_sec * 1000);
}

#endif
